################
Sphinx Terraform
################

.. container:: tagline

    A Sphinx_ extension for documenting Terraform modules.

    .. important:: **Terraform** and the Terraform Logo are trademarks
        of HashiCorp_.

See it in action in our documentation_.


.. _Sphinx: https://www.sphinx-doc.org/en/master/index.html
.. _HashiCorp: https://www.hashicorp.com/
.. _documentation: https://cblegare.gitlab.io/sphinx-terraform


Links
=====

- `Source code`_

.. _Source code:
